@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 
 import base64
 import re
@@ -134,7 +134,7 @@ def get_update_file(auth_token: str, repo_url) -> str or None:
         return None
 
 
-def get_all_files(auth_token: str, repo_url):
+def get_all_files(auth_token: str, tree_url, repo_url):
     session = requests.Session()
 
     headers = {
@@ -170,13 +170,14 @@ def main():
                 get_update_file(auth_token=token, repo_url=git_url)
         else:
             print(">> Could not find .git url")
-            git_url_input = input("Please enter the git url: ")
+            git_url_input = input("Please enter the [Project ID] that was given to you: ")
             git_url_input = git_url_input.rstrip('/')
             if git_url_input is not None:
                 is_empty = os.listdir(os.getcwd()) == []
                 if is_empty:
                     print(">> No files found in the current directory, downloading latest version...")
-                    get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1")
+                    get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
+                                  git_url_input)
                 else:
                     print(">> Found files in the current directory, updating latest version...")
                     get_update_file(auth_token=token, repo_url=git_url_input)
